@@ -32,7 +32,7 @@ from motor.motor_asyncio import (
     AsyncIOMotorDatabase,
 )
 
-from enochecker3.logging import ELKFormatter
+from enochecker3.logging import DebugFormatter, ELKFormatter
 from enochecker3.utils import FlagSearcher
 
 from .chaindb import ChainDB
@@ -107,10 +107,9 @@ class DependencyInjector:
         args = await self._exit_stack.enter_async_context(
             self.checker._inject_dependencies(self.task, injector, None)
         )
-        if isawaitable(injector):
-            res = await injector(*args)
-        else:
-            res = injector(*args)
+        res = injector(*args)
+        if isawaitable(res):
+            res = await res
 
         if not hasattr(res, "__enter__") and not hasattr(res, "__aenter__"):
             return res
@@ -118,23 +117,28 @@ class DependencyInjector:
 
 
 class Enochecker:
-    def __init__(self, name: str, service_port: int):
-        self.name: str = name
+    def __init__(self, service_name: str, service_port: int):
+        self.service_name: str = service_name
         self.service_port: int = service_port
 
+        self.checker_name: str = service_name + "Checker"
+
         self._dependency_injections: Dict[type, Callable[..., Any]] = {}
         self._logger: logging.Logger = logging.getLogger(__name__)
+
         handler = logging.StreamHandler(sys.stdout)
-        handler.setFormatter(ELKFormatter("%(message)s"))
+        if os.getenv("LOG_FORMAT") == "DEBUG":
+            handler.setFormatter(DebugFormatter("%(message)s"))
+        else:
+            handler.setFormatter(ELKFormatter("%(message)s"))
+
         self._logger.addHandler(handler)
         self._logger.setLevel(logging.DEBUG)
 
-        """
-        self._logger = logging.getLogger("uvicorn")
-        self._logger.setLevel(
-            logging.getLogger("uvicorn.access").getEffectiveLevel()
-        )
-        """
+        if __name__ == "uvicorn":
+            self._logger.setLevel(
+                logging.getLogger("uvicorn.access").getEffectiveLevel()
+            )
 
         self.register_dependency(self._get_http_client)
         self.register_dependency(self._get_chaindb)
@@ -173,7 +177,7 @@ class Enochecker:
             connection_string = f"mongodb://{mongo_host}:{mongo_port}"
 
         self._mongo: AsyncIOMotorClient = AsyncIOMotorClient(connection_string)
-        self._mongodb: AsyncIOMotorDatabase = self._mongo[self.name]
+        self._mongodb: AsyncIOMotorDatabase = self._mongo[self.checker_name]
 
         self._chain_collection: AsyncIOMotorCollection = self._mongodb["chain_db"]
 
@@ -261,10 +265,10 @@ class Enochecker:
                 async with self._inject_dependencies(
                     task, injector, dependencies.union([v.annotation])
                 ) as args_:
-                    if isawaitable(injector):
-                        args.append(await injector(*args_))
-                    else:
-                        args.append(injector(*args_))
+                    arg = injector(*args_)
+                    if isawaitable(arg):
+                        arg = await arg
+                    args.append(arg)
 
         async with AsyncExitStack() as stack:
             # new_args contains the return values of __(a)enter__, which would be the "x" in "(async) with ... as x:"
@@ -276,7 +280,7 @@ class Enochecker:
                 new_args.append(await stack.enter_async_context(arg))
             yield new_args
 
-    async def _call_method(self, task: BaseCheckerTaskMessage) -> Optional[str]:
+    async def _call_method_raw(self, task: BaseCheckerTaskMessage) -> Optional[str]:
         variant_id = task.variant_id
         method = task.method
         try:
@@ -287,9 +291,29 @@ class Enochecker:
             )
 
         async with self._inject_dependencies(task, f) as args:
+            return await f(*args)
+
+    async def _call_method(self, task: BaseCheckerTaskMessage) -> Optional[str]:
+        try:
             return await asyncio.wait_for(
-                f(*args), timeout=(task.timeout / 1000) - TIMEOUT_BUFFER
+                self._call_method_raw(task),
+                timeout=(task.timeout / 1000) - TIMEOUT_BUFFER,
             )
+        except asyncio.IncompleteReadError:
+            trace = traceback.format_exc()
+            logger = self._get_logger_adapter(task)
+            logger.error(f"Service connection closed abruptly\n{trace}")
+            raise MumbleException("Service connection closed abruptly")
+        except asyncio.TimeoutError:
+            trace = traceback.format_exc()
+            logger = self._get_logger_adapter(task)
+            logger.error(f"Service is responding too slow\n{trace}")
+            raise MumbleException("Service is responding too slow")
+        except (httpx.ConnectTimeout, httpx.ConnectError, httpx.RemoteProtocolError):
+            trace = traceback.format_exc()
+            logger = self._get_logger_adapter(task)
+            logger.info(f"HTTP connection to service failed\n{trace}")
+            raise OfflineException("HTTP connection to service failed")
 
     async def _call_putflag(
         self, task: PutflagCheckerTaskMessage
@@ -371,19 +395,24 @@ class Enochecker:
         return logging.LoggerAdapter(
             self._logger,
             extra={
-                "checker_name": self.name,
+                "service_name": self.service_name,
+                "checker_name": self.checker_name,
                 "checker_task": task,
             },
         )
 
     @contextlib.asynccontextmanager
-    async def _get_async_socket(self, task: BaseCheckerTaskMessage) -> AsyncSocket:
+    async def _get_async_socket(
+        self, task: BaseCheckerTaskMessage, logger: logging.LoggerAdapter
+    ) -> AsyncSocket:
         try:
             conn = await asyncio.streams.open_connection(
                 task.address, self.service_port
             )
-        except ConnectionError:
-            raise OfflineException("Establishing socket connection to service failed")
+        except:
+            trace = traceback.format_exc()
+            logger.info(f"Failed to connect to service\n{trace}")
+            raise OfflineException("Could not establish socket connection to service")
         try:
             yield conn
         finally:
@@ -441,7 +470,7 @@ class Enochecker:
         ) = self._validate_variant_ids()
 
         return CheckerInfoMessage(
-            service_name=self.name,
+            service_name=self.service_name,
             flag_variants=flag_variants,
             noise_variants=noise_variants,
             havoc_variants=havoc_variants,
@@ -472,6 +501,8 @@ class Enochecker:
         async def checker(task: CheckerTaskMessage) -> CheckerResultMessage:
             cls = METHOD_TO_TASK_MESSAGE_MAPPING[task.method]
             _task = cls(**task.dict())
+            logger = self._get_logger_adapter(_task)
+            logger.debug(f"Received new checker task with payload: {_task}")
             try:
                 if task.method == CheckerMethod.PUTFLAG:
                     return await self._call_putflag(
@@ -501,22 +532,27 @@ class Enochecker:
                         message=f"Unsupported method: {task.method}",
                     )
             except MumbleException as e:
-                traceback.print_exc()
+                trace = traceback.format_exc()
+                logger.info(f"Encountered mumble exception:\n{trace}")
                 return CheckerResultMessage(
                     result=CheckerTaskResult.MUMBLE, message=e.message
                 )
             except OfflineException as e:
-                traceback.print_exc()
+                trace = traceback.format_exc()
+                logger.info(f"Encountered offline exception:\n{trace}")
                 return CheckerResultMessage(
                     result=CheckerTaskResult.OFFLINE, message=e.message
                 )
             except InternalErrorException as e:
-                traceback.print_exc()
+                trace = traceback.format_exc()
+                logger.info(f"Encountered explicit internal error exception:\n{trace}")
                 return CheckerResultMessage(
                     result=CheckerTaskResult.INTERNAL_ERROR, message=e.message
                 )
             except Exception as e:
                 traceback.print_exc()
+                trace = traceback.format_exc()
+                logger.critical(f"Encountered internal exception:\n{trace}")
                 return CheckerResultMessage(
                     result=CheckerTaskResult.INTERNAL_ERROR,
                     message=f"Unhandled exception of type {type(e)}",
